@@ -145,12 +145,7 @@ sub unmake_readonly (\[$@%]@)  {
 }
 
 sub is_readonly (\[$@%]@) {
-	my $ref= reftype($_[0]) || "";
-	if ( $ref ) {
-		return _is_readonly($_[0], 0);
-	} else {
-		return _is_readonly(${$_[0]}, 0);
-	}
+	return _is_readonly($_[0], 0);
 }
 
 1;
